==> hs-xmlhtml-0.1.5.2.tgz: lib/ghc/xmlhtml-0.1.5.2/register.sh <==
#!/bin/sh
echo 'name: xmlhtml
version: 0.1.5.2
id: xmlhtml-0.1.5.2-d0e4c92666d97a0dfc681323b16375bf

license: BSD3
copyright:
maintainer: Chris Smith <cdsmith@gmail.com>
stability:
homepage:
package-url:
description: Contains renderers and parsers for both XML and HTML 5
             document fragments, which share data structures wo that
             it'\''s easy to work with both.  Document fragments are bits
             of documents, which are not constrained by some of the
             high-level structure rules (in particular, they may
             contain more than one root element).
             .
             Note that this is not a compliant HTML 5 parser.  Rather,
             it is a parser for HTML 5 compliant documents.  It does not
             implement the HTML 5 parsing algorithm, and should
             generally be expected to perform correctly only on
             documents that you trust to conform to HTML 5.  This is
             not a suitable library for implementing web crawlers or
             other software that will be exposed to documents from
             outside sources.  The result is also not the HTML 5
             node structure, but rather something closer to the physical
             structure.  For example, omitted start tags are not
             inserted (and so, their corresponding end tags must also be
             omitted).
category: Text
author: Chris Smith <cdsmith@gmail.com>
pkgpath: textproc/hs-xmlhtml
exposed: True
exposed-modules: Text.XmlHtml Text.XmlHtml.Cursor
                 Text.Blaze.Renderer.XmlHtml
hidden-modules: Text.XmlHtml.Common Text.XmlHtml.TextParser
                Text.XmlHtml.XML.Parse Text.XmlHtml.XML.Render
                Text.XmlHtml.HTML.Meta Text.XmlHtml.HTML.Parse
                Text.XmlHtml.HTML.Render
import-dirs: /usr/local/lib/ghc/xmlhtml-0.1.5.2
library-dirs: /usr/local/lib/ghc/xmlhtml-0.1.5.2
hs-libraries: HSxmlhtml-0.1.5.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
         blaze-builder-0.2.1.4-a9a25d33e6d6a838e2cd173ee4fe6a2b
         blaze-html-0.4.1.6-c6260218cba2fdc78ad752e5f040f9c6
         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
         parsec-3.1.1-ea1a88c91a616fb266a2214ec05870d5
         text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-xmlhtml-0.1.5.2/html/xmlhtml.haddock
haddock-html: /usr/local/share/doc/hs-xmlhtml-0.1.5.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-xmlhtml-0.2.0.2p1.tgz: lib/ghc/xmlhtml-0.2.0.2/register.sh <==
#!/bin/sh
echo 'name: xmlhtml
version: 0.2.0.2
id: xmlhtml-0.2.0.2-787261716cacb64ecb3a4e86590dd0e5

license: BSD3
copyright:
maintainer: Chris Smith <cdsmith@gmail.com>
stability:
homepage:
package-url:
synopsis: XML parser and renderer with HTML 5 quirks mode
description: Contains renderers and parsers for both XML and HTML 5
             document fragments, which share data structures so that
             it'\''s easy to work with both.  Document fragments are bits
             of documents, which are not constrained by some of the
             high-level structure rules (in particular, they may
             contain more than one root element).
             .
             Note that this is not a compliant HTML 5 parser.  Rather,
             it is a parser for HTML 5 compliant documents.  It does not
             implement the HTML 5 parsing algorithm, and should
             generally be expected to perform correctly only on
             documents that you trust to conform to HTML 5.  This is
             not a suitable library for implementing web crawlers or
             other software that will be exposed to documents from
             outside sources.  The result is also not the HTML 5
             node structure, but rather something closer to the physical
             structure.  For example, omitted start tags are not
             inserted (and so, their corresponding end tags must also be
             omitted).
category: Text
author: Chris Smith <cdsmith@gmail.com>
pkgpath: textproc/hs-xmlhtml
exposed: True
exposed-modules: Text.XmlHtml Text.XmlHtml.Cursor
                 Text.Blaze.Renderer.XmlHtml
hidden-modules: Text.XmlHtml.Common Text.XmlHtml.TextParser
                Text.XmlHtml.XML.Parse Text.XmlHtml.XML.Render
                Text.XmlHtml.HTML.Meta Text.XmlHtml.HTML.Parse
                Text.XmlHtml.HTML.Render
trusted: False
import-dirs: /usr/local/lib/ghc/xmlhtml-0.2.0.2
library-dirs: /usr/local/lib/ghc/xmlhtml-0.2.0.2
hs-libraries: HSxmlhtml-0.2.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         blaze-builder-0.2.1.4-7e5834be78fd9cd5b05f4a14f4001d18
         blaze-html-0.5.0.0-09f6e27ccba2168f1557f9c82181429a
         blaze-markup-0.5.1.0-6ef6c7afdc8718d3fd722a1fcd86e32b
         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         parsec-3.1.3-07e54fceec3486ec01b4c366cf3d07fd
         text-0.11.2.3-0a507fb72e97feed1b44644051bc0e5f
         unordered-containers-0.1.4.6-a7207f78d453daba3716dfc838a574ed
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-xmlhtml-0.2.0.2/html/xmlhtml.haddock
haddock-html: /usr/local/share/doc/hs-xmlhtml-0.2.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
